package info.aspirecn.iov.sjjh.supplier10000033.action;




import javax.servlet.http.HttpServletRequest;

import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000033.SjjhConstants;
import info.aspirecn.iov.sjjh.supplier10000033.service.Supplier10000033Service;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;

/**
 * 
 * @author bzh
 *
 */
@Slf4j
@RestController
public class Supplier10000033Action {
	/**日志参数中的错误参数名*/
	private static final String LOG_ERROR_PARA = "respnoseCode";
	/**日志参数中的是否收费*/
	private static final String LOG_FEE_PARA = "isCharge";
	
	@Autowired
	private Supplier10000033Service service;
	
	@ApiOperation(value = "获取公司信用详细信息查询接口", notes = "")
	@PostMapping(value = "/queryCompanyCreditDetails.do")
    public ChannelTypeHandleResponseObject queryCompanyCreditDetails(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
	
		//调用service
		ChannelTypeHandleResponseObject ret = service.queryCompanyCreditDetails(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("Supplier10000033Action.queryCompanyCreditDetails.Exception{}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	@ApiOperation(value = "获取公司信用详细信息查询接口-数据信用", notes = "")
	@PostMapping(value = "/queryCompanyCreditDetailsSjxy.do")
	public ChannelTypeHandleResponseObject queryCompanyCreditDetailsSjxy(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.queryCompanyCreditDetailsSjxy(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000033Action.queryCompanyCreditDetails.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}
	
	
	
	@ApiOperation(value = "企业工商数据查询模糊搜索", notes = "")
	@PostMapping(value = "/getCompanyCreditDetailsSearch.do")
    public ChannelTypeHandleResponseObject getCompanyCreditDetailsSearch(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getCompanyCreditDetailsSearch(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getCompanyCreditDetailsSearch.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "裁判文书查询", notes = "")
	@PostMapping(value = "/getSearchJudgmentDoc.do")
    public ChannelTypeHandleResponseObject getSearchJudgmentDoc(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSearchJudgmentDoc(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getSearchJudgmentDoc.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "裁判文书详情查询", notes = "")
	@PostMapping(value = "/getJudgementDetail.do")
    public ChannelTypeHandleResponseObject getJudgementDetail(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getJudgementDetail(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getJudgementDetail.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "失信信息查询", notes = "")
	@PostMapping(value = "/getSearchShiXin.do")
    public ChannelTypeHandleResponseObject getSearchShiXin(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSearchShiXin(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getSearchShiXin.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "被执行人信息查询", notes = "")
	@PostMapping(value = "/getSearchZhiXing.do")
    public ChannelTypeHandleResponseObject getSearchZhiXing(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSearchZhiXing(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getSearchZhiXing.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "法院公告列表信息查询", notes = "")
	@PostMapping(value = "/getSearchCourtAnnouncement.do")
    public ChannelTypeHandleResponseObject getSearchCourtAnnouncement(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSearchCourtAnnouncement(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getSearchCourtAnnouncement.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "开庭公告查询", notes = "")
	@PostMapping(value = "/getSearchCourtNotice.do")
    public ChannelTypeHandleResponseObject getSearchCourtNotice(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSearchCourtNotice(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getSearchCourtAnnouncementDetail.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "获取股权冻结信息", notes = "")
	@PostMapping(value = "/getJudicialAssistance.do")
    public ChannelTypeHandleResponseObject getJudicialAssistance(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getJudicialAssistance(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getJudicialAssistance.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "获取动产抵押信息", notes = "")
	@PostMapping(value = "/getChattelMortgage.do")
    public ChannelTypeHandleResponseObject getChattelMortgage(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getChattelMortgage(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getChattelMortgage.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
    
    @ApiOperation(value = "获取环保处罚列表", notes = "")
	@PostMapping(value = "/getEnvPunishmentList.do")
    public ChannelTypeHandleResponseObject getEnvPunishmentList(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getEnvPunishmentList(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getEnvPunishmentList.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
    
    @ApiOperation(value = "获取简易注销信息", notes = "")
	@PostMapping(value = "/getSimpleCancellation.do")
    public ChannelTypeHandleResponseObject getSimpleCancellation(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSimpleCancellation(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getSimpleCancellation.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
    
    @ApiOperation(value = "司法拍卖列表", notes = "")
	@PostMapping(value = "/getJudicialSaleList.do")
    public ChannelTypeHandleResponseObject getJudicialSaleList(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getJudicialSaleList(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getJudicialSaleList.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
    
    @ApiOperation(value = "获取土地抵押列表", notes = "")
	@PostMapping(value = "/getLandMortgageList.do")
    public ChannelTypeHandleResponseObject getLandMortgageList(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getLandMortgageList(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getLandMortgageList.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
    
    @ApiOperation(value = "获取严重违法信息", notes = "")
	@PostMapping(value = "/getSeriousViolationList.do")
    public ChannelTypeHandleResponseObject getSeriousViolationList(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		//调用service
		ChannelTypeHandleResponseObject ret = service.getSeriousViolationList(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("getLandMortgageList.encodeBase64String.Exception={}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
    
    @ApiOperation(value = "企业工商信息核验", notes = "")
   	@PostMapping(value = "/getInfo.do")
       public ChannelTypeHandleResponseObject getInfo(
       		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
       		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
       		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
   		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
   				.getRequest();
   		//调用service
   		ChannelTypeHandleResponseObject ret = service.getInfo(request, customBody, outTime);

           //把接口参数、调用结果和是否收费放入访问日志中
           if(ret.getCode() != Constant.SUCCESS) {
       		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
       	} else {
       		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
       	}
       	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

   		try {
   			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
   					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

       	} catch (Exception ex) {
       		ErrorUtils.captureException(ex);
       		log.error("getInfo.encodeBase64String.Exception={}", ex);
       	}
   		
   		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
           return ret;
   	}
}
